@@ -1,6 +1,6 @@
 /*
- renattach 1.2.2 - Filter that renames/deletes dangerous email attachments
- Copyright (C) 2003, 2004  Jem E. Berkes <jberkes@pc-tools.net>
+ renattach 1.2.3 - Filter that renames/deletes dangerous email attachments
+ Copyright (C) 2003-2005  Jem E. Berkes <jberkes@pc-tools.net>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,8 @@
 #include "renattach.h"
 #include "strings-en.h"
 #include "utility.h"
-#include "getopt.h"
+#include <ctype.h>
+#include <getopt.h>
 #include <memory.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -669,6 +670,10 @@ int is_line_mime(const char* line, int on_mime, struct attach* m_attachment)
 	{
 		int parsed_name = 0;				/* flag, was name parsed? */
 		char* nameloc = stristr(line, MIME_NAME);	/* case-insensitive search */
+
+		/* MIME_NAME should be before the first '=' sign */
+		if (nameloc >= strchr(line, '='))
+			nameloc = NULL;
 		
 		if (strncasecmp(line, MIME_CTYPE, sizeof(MIME_CTYPE)-1) == 0)
 		{
@@ -836,11 +841,15 @@ int filter_decision(struct attach* m_attach)
 		underscores alone make extension safe
 		Also tack on new extension if there is enough buffer space
 	*/
-	if (1 + strlen(m_attach->curspec->name) + strlen(configuration.new_extension)
-		< sizeof(m_attach->curspec->name))
+	/* bhoc@pentagroup.ch <mailto:bhoc@pentagroup.ch> : if new_exension is "#" then do nothing */
+	if (strcmp(configuration.new_extension, "#") != 0)
 	{
-		strcat(m_attach->curspec->name, ".");
-		strcat(m_attach->curspec->name, configuration.new_extension);
+		if (1 + strlen(m_attach->curspec->name) + strlen(configuration.new_extension)
+			< sizeof(m_attach->curspec->name))
+		{
+			strcat(m_attach->curspec->name, ".");
+			strcat(m_attach->curspec->name, configuration.new_extension);
+		}
 	}
 	/* Replace the Content-Type, since that is now suspicious */
 	strcpy(m_attach->content_type, configuration.new_mime_type);
